# User guide
The goal of this library is to make it as easy to use as possible. 
This page will list the documentation of the client function.
For examples, please check [the examples](macos-notifications/examples/).

::: mac_notifications.client.create_notification
